Learn R Programming

rcaiman (version 2.0.1)

calc_relative_radius: Calculate relative radius

Description

Convert zenith angles (degrees) to normalized radial distance using the lens projection model.

Usage

calc_relative_radius(angle, lens_coef)

Value

Numeric vector of the same length as angle, constrained to [0, 1].

Arguments

angle

numeric vector. Zenith angles in degrees.

lens_coef

numeric vector. Polynomial coefficients of the lens projection function. See lens().

Details

This helper maps zenith angle(s) to a relative radius in [0, 1] given the lens projection coefficients.

Examples

Run this code
calc_relative_radius(45, lens())

Run the code above in your browser using DataLab