Learn R Programming

rcaiman (version 2.0.1)

rcaiman-package: rcaiman: CAnopy IMage ANalysis

Description

Tools for preprocessing and processing canopy photographs with support for raw data reading. Provides methods to address variability in sky brightness and to mitigate errors from image acquisition in non-diffuse light. Works with all types of fish-eye lenses, and some methods also apply to conventional lenses.

Arguments

Author

Maintainer: Gastón Mauro Díaz gastonmaurodiaz@gmail.com (ORCID)

See Also