Learn R Programming

rcaiman (version 2.0.1)

thr_isodata: Compute IsoData threshold

Description

Compute a threshold using the IsoData algorithm isodata;textualrcaiman, recommended by Jonckheere2005;textualrcaiman.

Usage

thr_isodata(x)

Value

Numeric vector of length one.

Arguments

x

numeric vector or a single-column matrix or data.frame able to be coerced to numeric.

Details

Implementation follows the IsoData method by Gabriel Landini, as implemented in autothresholdr::auto_thresh(). Unlike that version, this function accepts numeric data over an arbitrary range. NA values are ignored.

References

Examples

Run this code
caim <- read_caim()
thr_isodata(caim$Blue[])

Run the code above in your browser using DataLab