powered by
Convert zenith angles (degrees) to normalized radial distance using the lens projection model.
calc_relative_radius(angle, lens_coef)
Numeric vector of the same length as angle, constrained to [0, 1].
angle
numeric vector. Zenith angles in degrees.
numeric vector. Polynomial coefficients of the lens projection function. See lens().
lens()
This helper maps zenith angle(s) to a relative radius in [0, 1] given the lens projection coefficients.
calc_relative_radius(45, lens())
Run the code above in your browser using DataLab