Generate an image of relative radiance or luminance based on the CIE
General Sky model.
Usage
cie_image(z, a, sun_angles, sky_coef)
Value
terra::SpatRaster with one layer whose pixel values
represent relative luminance or radiance across the sky hemisphere,
depending on whether the data used to obtain sky_coef was luminance
or radiance.